@@ -27,12 +27,12 @@ class CSVReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer, kwargs in self.streams:
-                self.__parse(handler=handler, buffer=buffer, **kwargs)
+            for handler, buffer in self.streams:
+                self.__parse(handler=handler, buffer=buffer)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None, **kwargs):
+    def __parse(self, handler=None, buffer=None):
         data = list()
         row_num = 0
         header = None
@@ -49,7 +49,7 @@ class CSVReader(FileHandler):
 
                 if handler and buffer <= len(data):
                     df = self.__to_df(data)
-                    handler(self.file_path, df, row_num - len(df) + 1, row_num, **kwargs)
+                    handler(self.file_path, df, row_num - len(df) + 1, row_num, **self.kwargs)
                     data.clear()
                     data.append(header)
 
@@ -64,7 +64,7 @@ class CSVReader(FileHandler):
 
         if not df.empty and handler:
             row_num -= 1
-            handler(self.file_path, df, row_num - len(df) + 1, row_num, **kwargs)
+            handler(self.file_path, df, row_num - len(df) + 1, row_num, **self.kwargs)
         elif not handler:
             return df
 
